@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/file75.tcl,v $
-# $Date: 1997/08/06 09:26:41 $
-# $Revision: 1.18.1.13 $
+# $Source: /home/nlfm/catless/Zircon/installer/RCS/file75.tcl,v $
+# $Date: 1998/09/07 12:01:47 $
+# $Revision: 1.18.1.14 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -23,3 +23,5 @@ proc copyfile {from to} {
 }
 #
 proc mkReadable {file} { exec chmod a+r $file }
+#
+proc mkExecutable {file} { exec chmod a+rx $file }
