@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Interface.tcl,v $
-# $Date: 1998/04/20 11:44:04 $
-# $Revision: 1.18.1.6 $
+# $Date: 1998/04/30 13:17:42 $
+# $Revision: 1.18.1.7 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -18,13 +18,13 @@ proc net_join {this chan args} {
 proc net_msg {this where what args} {
     switch {} $args { set chn nil } default { set chn [find $where $this] }
     switch $chn nil {
-    	$this qSend PRIVMSG $where :$what
+    	$this q1Send "PRIVMSG $where :$what"
     } default {
         $chn send $what
     }  
 }
 #
-proc net_notice {this where what args} { $this qSend NOTICE $where :$what }
+proc net_notice {this where what args} { $this q1Send "NOTICE $where :$what" }
 #
 proc net_echo {this where what args} {
     set chn [find $where $what]
