@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Server.tcl,v $
-# $Date: 1998/10/30 10:32:44 $
-# $Revision: 1.18.1.31 $
+# $Date: 1998/11/16 14:11:00 $
+# $Revision: 1.18.1.32 $
 #
 #
 package provide zircon 1.18
@@ -169,10 +169,12 @@ proc Server_pack {net} {
 proc Server_unpack {net} {
     upvar #0 ${net}STO newst
     foreach s [array names newst] { $newst($s) unpack $net}
-    Server :: cleanup new
+    Server :: cleanup $net new
 }
 #
-proc Server_cleanup {where} { }
+proc Server_cleanup {net where} {
+    foreach x [$net servers] { safeUnset ${where}$x }
+}
 #
 proc Server_find {name net} {
     upvar #0 STO$net STO
