@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/debug.tcl,v $
-# $Date: 1998/12/21 09:50:45 $
-# $Revision: 1.18.1.41 $
+# $Source: /home/nlfm/Working/Zircon/lib/RCS/debug.tcl,v $
+# $Date: 1999/07/23 09:17:37 $
+# $Revision: 1.18.1.42 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -167,8 +167,7 @@ proc zCtlQuit {} {
 	puts $y "*** Logging stopped [clock format [clock seconds]]"
 	close $y
     }
-    unset DBGL
-    catch {uplevel #0 unset zscr}
+    safeunset DBGL zscr
     destroy .@dbgctl
 }
 #
@@ -232,8 +231,7 @@ proc zDBGControl {} {
     global zscr zircon zlayout
     if {[winfo exists [set ctl .@dbgctl]]} { popup $ctl ; return }
     [MainControl].helpFrm.info.menu entryconfigure end -state normal
-    makeToplevel $ctl "Zircon Debugger" \
-      {catch {uplevel #0 unset zscr}} {}
+    makeToplevel $ctl "Zircon Debugger" {safeunset zscr} {}
     grid columnconfigure $ctl 0 -weight 1 -minsize 100
     set f [frame $ctl.btn]
     evenGrid $f column 0 3
@@ -277,8 +275,7 @@ proc doRDBG {usr net} {
 proc zDBGRemote {net usr} {
     global zscr zircon zlayout rdbg
     if {![winfo exists [set ctl .@dbgrem]]} {
-        makeToplevel $ctl "Zircon Remote Debugger" \
-          {catch {uplevel #0 unset zscr}} {}
+        makeToplevel $ctl "Zircon Remote Debugger" {safeunset zscr} {}
         grid columnconfigure $ctl 0 -weight 1 -minsize 100
         set f [frame $ctl.btn]
         button $f.close -text [trans dismiss] \
